
# Slot: timepoint


a point in time

URI: [biolink:timepoint](https://w3id.org/biolink/vocab/timepoint)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..1</sub> [TimeType](types/TimeType.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [BehavioralExposure](BehavioralExposure.md)
 * [BioticExposure](BioticExposure.md)
 * [ChemicalExposure](ChemicalExposure.md)
 * [ComplexChemicalExposure](ComplexChemicalExposure.md)
 * [DiseaseOrPhenotypicFeatureExposure](DiseaseOrPhenotypicFeatureExposure.md)
 * [DrugExposure](DrugExposure.md)
 * [DrugToGeneInteractionExposure](DrugToGeneInteractionExposure.md)
 * [EnvironmentalExposure](EnvironmentalExposure.md)
 * [ExposureEvent](ExposureEvent.md)
 * [GenomicBackgroundExposure](GenomicBackgroundExposure.md)
 * [GeographicExposure](GeographicExposure.md)
 * [GeographicLocationAtTime](GeographicLocationAtTime.md)
 * [PathologicalAnatomicalExposure](PathologicalAnatomicalExposure.md)
 * [PathologicalProcessExposure](PathologicalProcessExposure.md)
 * [SocioeconomicExposure](SocioeconomicExposure.md)
 * [Treatment](Treatment.md)
